@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_PREF_H_
 #define __GWEATHER_PREF_H_
 
-/* $Id: gweather-pref.h,v 1.4 2002/01/22 23:15:28 kevinv Exp $ */
+/* $Id: gweather-pref.h,v 1.5 2002/01/30 03:25:30 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -20,7 +20,7 @@ G_BEGIN_DECLS
 
 extern void gweather_pref_run (GWeatherApplet *gw_applet);
 
-extern void gweather_pref_load (const gchar *path, GWeatherApplet *gw_applet);
+extern void gweather_pref_load (GWeatherApplet *gw_applet);
 extern void gweather_pref_save (const gchar *path, GWeatherApplet *gw_applet);
 
 G_END_DECLS
