@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.23 2001/02/15 11:12:38 jberkman Exp $ */
+/* $Id: weather.c,v 1.31 2002/01/30 03:25:30 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -21,6 +21,9 @@
 #include <ctype.h>
 #include <math.h>
 
+#ifdef __FreeBSD__
+#include <sys/types.h>
+#endif
 #include <regex.h>
 #include <time.h>
 #include <unistd.h>
@@ -28,11 +31,13 @@
 #include <gnome.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
-#include <ghttp.h>
+#include <libgnomevfs/gnome-vfs.h>
 
-#include "http.h"
 #include "weather.h"
 
+void
+close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data);
+
 static WeatherUnits weather_units = UNITS_IMPERIAL;
 static WeatherForecastType weather_forecast = FORECAST_STATE;
 static gboolean weather_radar = FALSE;
@@ -41,6 +46,8 @@ static gchar *weather_proxy_url = NULL;
 static gchar *weather_proxy_user = NULL;
 static gchar *weather_proxy_passwd = NULL;
 
+#define DATA_SIZE 5000
+
 /* Unit conversions and names */
 
 #define TEMP_F_TO_C(f)  (((f) - 32.0) * 0.555556)
@@ -49,16 +56,16 @@ static gchar *weather_proxy_passwd = NULL;
 
 #define WINDSPEED_KNOTS_TO_KPH(knots)  ((knots) * 1.851965)
 #define WINDSPEED_KPH_TO_KNOTS(kph)    ((kph) * 0.539967)
-#define WINDSPEED_UNIT_STR(units) (((units) == UNITS_IMPERIAL) ? "knots" : "kph")
+#define WINDSPEED_UNIT_STR(units) (((units) == UNITS_IMPERIAL) ? _("knots") : _("kph"))
 
 #define PRESSURE_INCH_TO_MM(inch)   ((inch) * 25.4)
 #define PRESSURE_MM_TO_INCH(mm)     ((mm) * 0.03937)
 #define PRESSURE_MBAR_TO_INCH(mbar) ((mbar) * 0.02963742)
-#define PRESSURE_UNIT_STR(units) (((units) == UNITS_IMPERIAL) ? "inHg" : "mmHg")
+#define PRESSURE_UNIT_STR(units) (((units) == UNITS_IMPERIAL) ? _("inHg") : _("mmHg"))
 
 #define VISIBILITY_SM_TO_KM(sm)  ((sm) * 1.609344)
 #define VISIBILITY_KM_TO_SM(km)  ((km) * 0.621371)
-#define VISIBILITY_UNIT_STR(units) (((units) == UNITS_IMPERIAL) ? "miles" : "kilometers")
+#define VISIBILITY_UNIT_STR(units) (((units) == UNITS_IMPERIAL) ? _("miles") : _("kilometers"))
 
 
 WeatherLocation *weather_location_new (const gchar *name, const gchar *code, const gchar *zone, const gchar *radar)
@@ -93,29 +100,16 @@ void weather_location_config_write (gchar *prefix, WeatherLocation *location)
     g_free(locdata);
 }
 
-WeatherLocation *weather_location_config_read (gchar *prefix)
+WeatherLocation *weather_location_config_read (PanelApplet *applet)
 {
     WeatherLocation *location;
-    gchar **locdata;
-    gint nlocdata;
-    gchar *prefix_with_default;
 
-    g_return_val_if_fail(prefix != NULL, NULL);
-
-    prefix_with_default = g_strconcat(prefix, "=Pittsburgh KPIT PAZ021 pit", NULL);
-
-    gnome_config_get_vector(prefix_with_default, &nlocdata, &locdata);
-
-    if (nlocdata != 4) {
-	    g_warning (_("Location vector needs to be 4 elements long"));
-	    g_free(prefix_with_default);
-	    g_strfreev(locdata);
-	    return NULL;
-    }
-    location = weather_location_new(locdata[0], locdata[1], locdata[2], locdata[3]);
-    g_strfreev(locdata);
-
-    g_free(prefix_with_default);
+	location = weather_location_new(
+			panel_applet_gconf_get_string(applet, "location0", NULL),
+			panel_applet_gconf_get_string(applet, "location1", NULL),
+			panel_applet_gconf_get_string(applet, "location2", NULL),
+			panel_applet_gconf_get_string(applet, "location3", NULL)
+		);
 
     return location;
 }
@@ -242,11 +236,17 @@ const gchar *weather_conditions_string (WeatherConditions cond)
 
 static WeatherInfoFunc request_cb = NULL;
 static WeatherInfo *request_info = NULL;
+/*
 static ghttp_request *metar_request = NULL,
                      *iwin_request = NULL,
                      *wx_request = NULL,
                      *met_request = NULL;
-                     
+*/
+static GnomeVFSAsyncHandle *metar_handle = NULL,
+										*iwin_handle = NULL,
+										*wx_handle = NULL,
+										*met_handle = NULL;
+										
 static gboolean requests_pending = FALSE;
 
 static __inline gboolean requests_init (WeatherInfoFunc cb, WeatherInfo *info)
@@ -254,29 +254,30 @@ static __inline gboolean requests_init (WeatherInfoFunc cb, WeatherInfo *info)
     if (requests_pending)
         return FALSE;
 
-    g_assert(!metar_request && !iwin_request && !wx_request && !met_request);
+    g_assert(!metar_handle && !iwin_handle && !wx_handle && !met_handle);
     g_assert(!request_info && !request_cb);
 
     requests_pending = TRUE;
     request_cb = cb;
     request_info = info;
-
+	
     return TRUE;
 }
 
-static inline void request_done (ghttp_request **req)
+static inline void request_done (GnomeVFSAsyncHandle *handle)
 {
-    g_return_if_fail(req != NULL);
+    g_return_if_fail(handle != NULL);
 
-    ghttp_request_destroy(*req);
-    *req = NULL;
+    gnome_vfs_async_close(handle, close_cb, NULL);
+    
+    return;
 }
 
 static inline void requests_done_check (void)
 {
     g_return_if_fail(requests_pending);
 
-    if (!metar_request && !iwin_request && !wx_request && !met_request) {
+    if (!metar_handle && !iwin_handle && !wx_handle && !met_handle) {
         requests_pending = FALSE;
         /* Next two lines temporarily here */
         if (weather_units == UNITS_METRIC)
@@ -287,6 +288,26 @@ static inline void requests_done_check (void)
     }
 }
 
+void
+close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
+{
+	if (result != GNOME_VFS_OK)
+		g_warning("Error closing GnomeVFSAsyncHandle.\n");
+	
+	if (handle == metar_handle)
+		metar_handle = NULL;
+	if (handle == iwin_handle)
+		iwin_handle = NULL;
+	if (handle == wx_handle)
+		wx_handle = NULL;
+	if (handle == met_handle)
+		met_handle = NULL;
+	
+	requests_done_check();
+		
+	return;
+}
+
 #define TIME_RE_STR  "^([0-9]{6})Z$"
 #define WIND_RE_STR  "^(([0-9]{3})|VRB)([0-9]?[0-9]{2})(G[0-9]?[0-9]{2})?KT$"
 #define VIS_RE_STR   "^(([0-9]?[0-9])|(M?1/[0-9]?[0-9]))SM$"
@@ -758,8 +779,6 @@ static gboolean metar_parse (gchar *metar, WeatherInfo *info)
 
     metar_init_re();
 
-    /* fprintf(stderr, "metar_parse: %s\n", metar); */
-
     toks = g_strsplit(metar, " ", 0);
 
     for (ntoks = 0;  toks[ntoks];  ntoks++)
@@ -779,45 +798,37 @@ static gboolean metar_parse (gchar *metar, WeatherInfo *info)
     return TRUE;
 }
 
-static void metar_get_finish (ghttp_request *req, ghttp_status status, gpointer data)
+static void metar_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer buffer,
+										GnomeVFSFileSize requested, GnomeVFSFileSize body_len, gpointer data)
 {
     WeatherInfo *info = (WeatherInfo *)data;
     WeatherLocation *loc;
-    gchar *body;
-    int body_len;
-    gchar *metar, *eoln;
+    gchar *metar, *eoln, *body, *temp;
     gboolean success = FALSE;
     gchar searchkey[WEATHER_LOCATION_CODE_LEN + 2];
 
-    g_return_if_fail(req == metar_request);
-
-    g_return_if_fail(info != NULL);
     info->forecast = NULL;
     loc = info->location;
-    if (loc == NULL) {
-	    g_warning (_("WeatherInfo missing location"));
-	    request_done(&metar_request);
-	    requests_done_check();
-	    return;
+    body = (gchar *)buffer;
+
+    body[body_len] = '\0';
+
+    if (info->metar_buffer == NULL)
+      info->metar_buffer = g_strdup(body);
+    else
+    {
+	temp = g_strdup(info->metar_buffer);
+	g_free(info->metar_buffer);
+	info->metar_buffer = g_strdup_printf("%s%s", temp, body);
+	g_free(temp);
     }
+		
+    if (result == GNOME_VFS_ERROR_EOF)
+    {
 
-    if (status == ghttp_error) {
-        g_warning(_("Failed to get METAR data.\n"));
-    } else {
-        body = ghttp_get_body(metar_request);
-        body_len = ghttp_get_body_len(metar_request);
+  	g_snprintf (searchkey, sizeof (searchkey), "\n%s", loc->code);
 
-	if (body == NULL ||
-	    body_len <= 0) {
-		request_done(&metar_request);
-		requests_done_check();
-		return;
-	}
-
-        body[body_len-1] = 0;  /* quick hack */
-
-        g_snprintf (searchkey, sizeof (searchkey), "\n%s", loc->code);
-        metar = strstr(body, searchkey);
+        metar = strstr(info->metar_buffer, searchkey);
         if (metar == NULL) {
             success = FALSE;
         } else {
@@ -831,13 +842,58 @@ static void metar_get_finish (ghttp_request *req, ghttp_status status, gpointer
         }
 
         info->valid = success;
+	}
+	else if (result != GNOME_VFS_OK) {
+	    g_print("%s", gnome_vfs_result_to_string(result));
+        g_warning(_("Failed to get METAR data.\n"));
+    } else {
+	gnome_vfs_async_read(handle, body, DATA_SIZE - 1, metar_finish_read, info);
+
+	return;      
     }
-    request_done(&metar_request);
-    requests_done_check();
+    
+    request_done(metar_handle);
+    
+    return;
+}
+
+static void metar_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
+{
+    WeatherInfo *info = (WeatherInfo *)data;
+    WeatherLocation *loc;
+    gchar *body;
+    int body_len;
+    gchar *metar, *eoln;
+    gboolean success = FALSE;
+    gchar searchkey[WEATHER_LOCATION_CODE_LEN + 2];
+
+    g_return_if_fail(handle == metar_handle);
+
+    g_return_if_fail(info != NULL);
+    
+    body = g_malloc0(DATA_SIZE);
+    
+    info->metar_buffer = NULL;
+    info->forecast = NULL;
+    loc = info->location;
+    if (loc == NULL) {
+	    g_warning (_("WeatherInfo missing location"));
+	    request_done(metar_handle);
+	    requests_done_check();
+	    return;
+    }
+
+    if (result != GNOME_VFS_OK) {
+        g_warning(_("Failed to get METAR data.\n"));
+    } else {
+        gnome_vfs_async_read(handle, body, DATA_SIZE - 1, metar_finish_read, info);
+	}
+
+    return;
 }
 
 /* Read current conditions and fill in info structure */
-static void metar_get_start (WeatherInfo *info)
+static void metar_start_open (WeatherInfo *info)
 {
     gchar *url;
     WeatherLocation *loc;
@@ -850,15 +906,16 @@ static void metar_get_start (WeatherInfo *info)
 	    return;
     }
 
-    metar_request = ghttp_request_new();
     url = g_strdup_printf("http://weather.noaa.gov/cgi-bin/mgetmetar.pl?cccc=%s", loc->code);
-    ghttp_set_uri(metar_request, url);
+    gnome_vfs_async_open(&metar_handle, url, GNOME_VFS_OPEN_READ, 0, metar_finish_open, info);
     g_free(url);
+/*
     ghttp_set_proxy(metar_request, weather_proxy_url);
     ghttp_set_proxy_authinfo(metar_request, weather_proxy_user, weather_proxy_passwd);
     ghttp_set_header(metar_request, http_hdr_Connection, "close");
 
     http_process_bg(metar_request, metar_get_finish, info);
+*/
 }
 
 #define IWIN_RE_STR "([A-Z][A-Z]Z(([0-9]{3}>[0-9]{3}-)|([0-9]{3}-))+)+([0-9]{6}-)?"
@@ -951,9 +1008,7 @@ static gchar *iwin_parse (gchar *iwin, WeatherLocation *loc)
     g_return_val_if_fail(loc != NULL, NULL);
     if (loc->name[0] == '-')
         return NULL;
-
-    /* fprintf(stderr, "iwin_parse\n"); */
-
+	
     iwin_init_re();
 
     p = iwin;
@@ -963,12 +1018,14 @@ static gchar *iwin_parse (gchar *iwin, WeatherLocation *loc)
         *p = ' ';
 
     p = iwin;
-    
+
     while ((ret = regexec(&iwin_re, p, 1, match, 0)) != REG_NOMATCH) {
         rangep = p + match[0].rm_so;
         p = strchr(rangep, '\n');
         if (iwin_range_match(rangep, loc)) 
+        {
             break;
+		}
     }
 
     if (ret != REG_NOMATCH) {
@@ -984,7 +1041,49 @@ static gchar *iwin_parse (gchar *iwin, WeatherLocation *loc)
 
 }
 
-static void iwin_get_finish (ghttp_request *req, ghttp_status status, gpointer data)
+static void iwin_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer buffer,
+										GnomeVFSFileSize requested, GnomeVFSFileSize body_len, gpointer data)
+{
+	WeatherInfo *info = (WeatherInfo *)data;
+    WeatherLocation *loc;
+	gchar *body, *temp;
+	gchar *forecast;
+
+	info->forecast = NULL;
+    loc = info->location;
+	body = (gchar *)buffer;
+	body[body_len] = '\0';
+
+	if (info->iwin_buffer == NULL)
+		info->iwin_buffer = g_strdup(body);
+	else
+	{
+		temp = g_strdup(info->iwin_buffer);
+		g_free(info->iwin_buffer);
+		info->iwin_buffer = g_strdup_printf("%s%s", temp, body);
+		g_free(temp);
+	}
+	
+	if (result == GNOME_VFS_ERROR_EOF)
+	{
+		forecast = iwin_parse(info->iwin_buffer, loc);
+		info->forecast = forecast;
+	}
+	else if (result != GNOME_VFS_OK) {
+		g_print("%s", gnome_vfs_result_to_string(result));
+        g_warning(_("Failed to get IWIN data.\n"));
+    } else {
+		gnome_vfs_async_read(handle, body, DATA_SIZE - 1, iwin_finish_read, info);
+
+		return;
+    }
+    
+    request_done(iwin_handle);
+    
+	return;
+}
+
+static void iwin_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
 {
     WeatherInfo *info = (WeatherInfo *)data;
     WeatherLocation *loc;
@@ -992,39 +1091,30 @@ static void iwin_get_finish (ghttp_request *req, ghttp_status status, gpointer d
     gint body_len;
     gchar *forecast;
 
-    g_return_if_fail(req == iwin_request);
-
+    g_return_if_fail(handle == iwin_handle);
+	
     g_return_if_fail(info != NULL);
+
+	body = g_malloc0(DATA_SIZE);
+
+	info->iwin_buffer = NULL;	
     g_free (info->forecast);
     info->forecast = NULL;
     loc = info->location;
     if (loc == NULL) {
 	    g_warning (_("WeatherInfo missing location"));
-	    request_done(&iwin_request);
+	    request_done(iwin_handle);
 	    requests_done_check();
 	    return;
     }
 
-    if (status == ghttp_error) {
+    if (result != GNOME_VFS_OK) {
         g_warning(_("Failed to get IWIN forecast data.\n"));
     } else {
-        body = ghttp_get_body(iwin_request);
-        body_len = ghttp_get_body_len(iwin_request);
-
-	if (body == NULL ||
-	    body_len <= 0) {
-		request_done(&iwin_request);
-		requests_done_check();
-		return;
+        gnome_vfs_async_read(handle, body, DATA_SIZE - 1, iwin_finish_read, info);
 	}
-        body[body_len-1] = 0;  /* quick hack */
-
-        forecast = iwin_parse(body, loc);
-        info->forecast = forecast;
-    }
-
-    request_done(&iwin_request);
-    requests_done_check();
+	
+	return;
 }
 
 static char *met_reprocess(char *x, int len)
@@ -1184,7 +1274,50 @@ static gchar *met_parse (gchar *meto, WeatherLocation *loc)
     return r;
 }
 
-static void met_get_finish (ghttp_request *req, ghttp_status status, gpointer data)
+static void met_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result, 
+			    gpointer buffer, GnomeVFSFileSize requested, 
+			    GnomeVFSFileSize body_len, gpointer data)
+{
+	WeatherInfo *info = (WeatherInfo *)data;
+    WeatherLocation *loc;
+    gchar *body, *forecast, *temp;
+g_print ("read met \n");
+	info->forecast = NULL;
+    loc = info->location;
+	body = (gchar *)buffer;
+	body[body_len] = '\0';
+	
+	if (info->met_buffer == NULL)
+		info->met_buffer = g_strdup(body);
+	else
+	{
+		temp = g_strdup(info->met_buffer);
+		g_free(info->met_buffer);
+		info->met_buffer = g_strdup_printf("%s%s", temp, body);
+		g_free(temp);
+	}
+	
+	if (result == GNOME_VFS_ERROR_EOF)
+	{
+		g_print ("%s \n", info->met_buffer);
+		forecast = met_parse(info->met_buffer, loc);
+        info->forecast = forecast;
+    }
+	else if (result != GNOME_VFS_OK) {
+		g_print("%s", gnome_vfs_result_to_string(result));
+        g_warning(_("Failed to get Met Office data.\n"));
+    } else {
+		gnome_vfs_async_read(handle, body, DATA_SIZE - 1, met_finish_read, info);
+
+		return;
+    }
+    
+    request_done(met_handle);
+    
+	return;
+}
+
+static void met_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
 {
     WeatherInfo *info = (WeatherInfo *)data;
     WeatherLocation *loc;
@@ -1192,55 +1325,42 @@ static void met_get_finish (ghttp_request *req, ghttp_status status, gpointer da
     gint body_len;
     gchar *forecast;
 
-    g_return_if_fail(req == met_request);
+    g_return_if_fail(handle == met_handle);
 
     g_return_if_fail(info != NULL);
+g_print ("finish open \n");
+	body = g_malloc0(DATA_SIZE);
+
+	info->met_buffer = NULL;	
     info->forecast = NULL;
     loc = info->location;
     g_return_if_fail(loc != NULL);
 
-    if (status == ghttp_error) {
+    if (result != GNOME_VFS_OK) {
         g_warning(_("Failed to get Met Office forecast data.\n"));
     } else {
-        body = ghttp_get_body(met_request);
-        body_len = ghttp_get_body_len(met_request);
-        if(body==NULL || body_len == 0)
-        {
-	    request_done(&iwin_request);
-	    requests_done_check();
-	    return;
+		gnome_vfs_async_read(handle, body, DATA_SIZE - 1, met_finish_read, info);
 	}
-        
-        body[body_len-1] = 0;  /* quick hack */
 
-        forecast = met_parse(body, loc);
-        info->forecast = forecast;
-    }
-
-    request_done(&met_request);
-    requests_done_check();
+	return;
 }
 
-static void metoffice_get_start (WeatherInfo *info)
+static void metoffice_start_open (WeatherInfo *info)
 {
     gchar *url;
     WeatherLocation *loc;
     loc = info->location;
-
-    met_request = ghttp_request_new();
-    
+  
     url = g_strdup_printf("http://www.metoffice.gov.uk/datafiles/%s.html", loc->zone+1);
-    ghttp_set_uri(met_request, url);
+g_print ("%s \n", url);
+    gnome_vfs_async_open(&met_handle, url, GNOME_VFS_OPEN_READ, 0, met_finish_open, info);
     g_free(url);
-    ghttp_set_proxy(met_request, weather_proxy_url);
-    ghttp_set_proxy_authinfo(met_request, weather_proxy_user, weather_proxy_passwd);
-    ghttp_set_header(met_request, http_hdr_Connection, "close");
 
-    http_process_bg(met_request, met_get_finish, info);
+    return;
 }	
 
 /* Get forecast into newly alloc'ed string */
-static void iwin_get_start (WeatherInfo *info)
+static void iwin_start_open (WeatherInfo *info)
 {
     gchar state[WEATHER_LOCATION_ZONE_LEN];
     gchar *url;
@@ -1256,24 +1376,19 @@ static void iwin_get_start (WeatherInfo *info)
         
     if (loc->zone[0] == ':')	/* Met Office Region Names */
     {
-    	metoffice_get_start (info);
+    	metoffice_start_open (info);
     	return;
     }
 
     strncpy(state, loc->zone, 2);
     state[2] = 0;
-    iwin_request = ghttp_request_new();
     if (weather_forecast == FORECAST_ZONE)
         url = g_strdup_printf("http://iwin.nws.noaa.gov/iwin/%s/zone.html", state);
     else
         url = g_strdup_printf("http://iwin.nws.noaa.gov/iwin/%s/state.html", state);
-    ghttp_set_uri(iwin_request, url);
+    gnome_vfs_async_open(&iwin_handle, url, GNOME_VFS_OPEN_READ, 0, iwin_finish_open, info);
     g_free(url);
-    ghttp_set_proxy(iwin_request, weather_proxy_url);
-    ghttp_set_proxy_authinfo(iwin_request, weather_proxy_user, weather_proxy_passwd);
-    ghttp_set_header(iwin_request, http_hdr_Connection, "close");
 
-    http_process_bg(iwin_request, iwin_get_finish, info);
 }
 
 static GdkPixmap *wx_construct (gpointer data, gint data_len)
@@ -1282,12 +1397,10 @@ static GdkPixmap *wx_construct (gpointer data, gint data_len)
     GdkPixbuf *pixbuf;
     GdkPixbufLoader *pixbuf_loader;
 
-    /* fprintf(stderr, "wx_get\n"); */
-
     pixbuf_loader = gdk_pixbuf_loader_new ();
 
-    gdk_pixbuf_loader_write (pixbuf_loader, data, data_len);
-    gdk_pixbuf_loader_close (pixbuf_loader);
+    gdk_pixbuf_loader_write (pixbuf_loader, data, data_len, NULL);
+    gdk_pixbuf_loader_close (pixbuf_loader, NULL);
 
     pixbuf = gdk_pixbuf_loader_get_pixbuf (pixbuf_loader);
 
@@ -1295,14 +1408,60 @@ static GdkPixmap *wx_construct (gpointer data, gint data_len)
 
     if (pixbuf != NULL) {
 	    gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, NULL, 127);
+	    g_print ("pixbud != NULL\n");
     }
 
-    gtk_object_unref (GTK_OBJECT (pixbuf_loader));
+    g_object_unref (G_OBJECT (pixbuf_loader));
 
     return pixmap;
 }
 
-static void wx_get_finish (ghttp_request *req, ghttp_status status, gpointer data)
+static void wx_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result, 
+			   gpointer buffer, GnomeVFSFileSize requested, 
+			   GnomeVFSFileSize body_len, gpointer data)
+{
+    WeatherInfo *info = (WeatherInfo *)data;
+    WeatherLocation *loc;
+    gchar *body, *temp;
+    GdkPixmap *pixmap = NULL;
+	
+	info->forecast = NULL;
+	info->radar = NULL;
+    loc = info->location;
+	body = (gchar *)buffer;
+	body[body_len] = '\0';
+
+	if (info->radar_buffer == NULL)
+		info->radar_buffer = g_strdup(body);
+	else
+	{
+		temp = g_strdup(info->radar_buffer);
+		g_free(info->radar_buffer);
+		info->radar_buffer = g_strdup_printf("%s%s", temp, body);
+		g_free(temp);
+	}
+	
+	if (result == GNOME_VFS_ERROR_EOF)
+	{
+		pixmap = wx_construct (info->radar_buffer, strlen (info->radar_buffer));
+g_print ("got radar \n");
+        info->radar = pixmap;
+	}
+	else if (result != GNOME_VFS_OK) {
+		g_print("%s", gnome_vfs_result_to_string(result));
+        g_warning(_("Failed to get METAR data.\n"));
+    } else {
+		gnome_vfs_async_read(handle, body, DATA_SIZE - 1, wx_finish_read, info);
+
+		return;
+    }
+
+	request_done(wx_handle);
+	    
+	return;
+}
+
+static void wx_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
 {
     WeatherInfo *info = (WeatherInfo *)data;
     WeatherLocation *loc;
@@ -1310,35 +1469,31 @@ static void wx_get_finish (ghttp_request *req, ghttp_status status, gpointer dat
     gint body_len;
     GdkPixmap *pixmap = NULL;
 
-    g_return_if_fail(req == wx_request);
+    g_return_if_fail(handle == wx_handle);
 
     g_return_if_fail(info != NULL);
+
+    body = g_malloc0(DATA_SIZE);
+
+    info->radar_buffer = NULL;	
     info->radar = NULL;
     loc = info->location;
     g_return_if_fail(loc != NULL);
 
-    if (status == ghttp_error) {
+    if (result != GNOME_VFS_OK) {
         g_warning(_("Failed to get radar map image.\n"));
     } else {
-        body = ghttp_get_body(wx_request);
-        body_len = ghttp_get_body_len(wx_request);
-        g_return_if_fail(body != NULL);
-        g_return_if_fail(body_len > 0);
-
-        pixmap = wx_construct(body, body_len);
-        info->radar = pixmap;
+    	gnome_vfs_async_read(handle, body, DATA_SIZE -1, wx_finish_read, info);
     }
-
-    request_done(&wx_request);
-    requests_done_check();
+     return;
 }
 
 /* Get radar map and into newly allocated pixmap */
-static void wx_get_start (WeatherInfo *info)
+static void wx_start_open (WeatherInfo *info)
 {
     gchar *url;
     WeatherLocation *loc;
-
+	
     g_return_if_fail(info != NULL);
     info->radar = NULL;
     loc = info->location;
@@ -1348,14 +1503,11 @@ static void wx_get_start (WeatherInfo *info)
         return;
 
     url = g_strdup_printf("http://image.weather.com/images/radar/single_site/%sloc_450x284.jpg", loc->radar);
-    wx_request = ghttp_request_new();
-    ghttp_set_uri(wx_request, url);
+g_print ("url %s \n", url);
+    gnome_vfs_async_open(&wx_handle, url, GNOME_VFS_OPEN_READ, 0, wx_finish_open, info);
     g_free(url);
-    ghttp_set_proxy(wx_request, weather_proxy_url);
-    ghttp_set_proxy_authinfo(wx_request, weather_proxy_user, weather_proxy_passwd);
-    ghttp_set_header(wx_request, http_hdr_Connection, "close");
 
-    http_process_bg(wx_request, wx_get_finish, info);
+    return;
 }
 
 gboolean _weather_info_fill (WeatherInfo *info, WeatherLocation *location, WeatherInfoFunc cb)
@@ -1363,20 +1515,22 @@ gboolean _weather_info_fill (WeatherInfo *info, WeatherLocation *location, Weath
     g_return_val_if_fail(((info == NULL) && (location != NULL)) || \
                          ((info != NULL) && (location == NULL)), FALSE);
 
+    /* FIXME: i'm not sure this works as intended anymore */
     if (!info) {
         info = g_new(WeatherInfo, 1);
         info->location = weather_location_clone(location);
     } else {
         location = info->location;
-        g_free(info->forecast);
-        info->forecast = NULL;
-	if (info->radar != NULL) {
-		gdk_pixmap_unref (info->radar);
-		info->radar = NULL;
-	}
+        /* g_free(info->forecast); */
+	    info->forecast = NULL;
+		if (info->radar != NULL) {
+			gdk_pixmap_unref (info->radar);
+			info->radar = NULL;
+		}
     }
 
     /* FIX */
+    
     if (!requests_init(cb, info)) {
         g_warning(_("Another update already in progress!\n"));
         return FALSE;
@@ -1399,12 +1553,11 @@ gboolean _weather_info_fill (WeatherInfo *info, WeatherLocation *location, Weath
     info->forecast = NULL;
     info->radar = NULL;
 
-    metar_get_start(info);
- 
-    iwin_get_start(info);
+    metar_start_open(info);
+    iwin_start_open(info);
 
     if (weather_radar)
-        wx_get_start(info);
+        wx_start_open(info);
 
     return TRUE;
 }
@@ -1435,10 +1588,10 @@ void weather_info_config_write (WeatherInfo *info)
     /* info->radar = NULL; */
 }
 
-WeatherInfo *weather_info_config_read (void)
+WeatherInfo *weather_info_config_read (PanelApplet *applet)
 {
     WeatherInfo *info = g_new(WeatherInfo, 1);
-
+/*
     info->valid = gnome_config_get_bool("valid=FALSE");
     info->location = weather_location_config_read("location");
     info->units = (WeatherUnits)gnome_config_get_int("units=0");
@@ -1455,6 +1608,24 @@ WeatherInfo *weather_info_config_read (void)
     info->pressure = gnome_config_get_float("pressure=0");
     info->visibility = gnome_config_get_float("visibility=0");
     info->forecast = gnome_config_get_string("forecast=None");
+    info->radar = NULL;
+*/
+	info->valid = FALSE;
+    info->location = weather_location_config_read(applet);
+    info->units = (WeatherUnits)0;
+    info->update = (WeatherUpdate)0;
+    info->sky = (WeatherSky)0;
+    info->cond.significant = FALSE;
+    info->cond.phenomenon = (WeatherConditionPhenomenon)0;
+    info->cond.qualifier = (WeatherConditionQualifier)0;
+    info->temp = 0;
+    info->dew = 0;
+    info->humidity = 0;
+    info->wind = (WeatherWindDirection)0;
+    info->windspeed = 0;
+    info->pressure = 0;
+    info->visibility = 0;
+    info->forecast = "None";
     info->radar = NULL;  /* FIX */
 
     return info;
@@ -1715,7 +1886,7 @@ const gchar *weather_info_get_temp_summary (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "--";
-    g_snprintf(buf, sizeof (buf), "%d\260", (int)info->temp);
+    g_snprintf(buf, sizeof (buf), "%d\260", (int)(info->temp + 0.5));
     return buf;
 }
 
