@@ -20,7 +20,7 @@ static void
 load_graph_draw (LoadGraph *g)
 {
     guint i, j;
-
+	
     /* we might get called before the configure event so that
      * g->disp->allocation may not have the correct size
      * (after the user resized the applet in the prop dialog). */
@@ -80,7 +80,7 @@ load_graph_draw (LoadGraph *g)
 		     0, 0,
 		     g->disp->allocation.width,
 		     g->disp->allocation.height);
-
+	
     for (i = 0; i < g->draw_width; i++)
 		memcpy (g->odata [i], g->data [i], g->data_size);
 	
@@ -95,8 +95,8 @@ load_graph_update (LoadGraph *g)
 
 	if (g->tooltip_update)
 		multiload_applet_tooltip_update(g);
-		
-    g->get_data (g->draw_height, g->data [0], g);
+	else		
+	    g->get_data (g->draw_height, g->data [0], g);
 
     for (i=0; i < g->draw_width-1; i++)
 		for (j=0; j < g->n; j++)
@@ -176,14 +176,6 @@ load_graph_alloc (LoadGraph *g)
 /*    g->show_frame = pixel_size > 36;	*/
 	g->show_frame = 1;
 
-    if (g->orient) {
-		g->draw_width = g->pixel_size;
-		g->draw_height = g->size;
-    } else {
-		g->draw_width = g->size;
-		g->draw_height = g->pixel_size;
-    }
-	
     g->data = g_new0 (guint *, g->draw_width);
     g->odata = g_new0 (guint *, g->draw_width);
     g->pos = g_new0 (guint, g->draw_width);
@@ -203,8 +195,12 @@ load_graph_configure (GtkWidget *widget, GdkEventConfigure *event,
 		      gpointer data_ptr)
 {
     LoadGraph *c = (LoadGraph *) data_ptr;
-
+	
     load_graph_unalloc (c);
+    
+    c->draw_width = c->disp->allocation.width;
+	c->draw_height = c->disp->allocation.height;;
+	
     load_graph_alloc (c);
 
     if (!c->pixmap)
@@ -225,6 +221,7 @@ load_graph_configure (GtkWidget *widget, GdkEventConfigure *event,
 		     0, 0,
 		     c->disp->allocation.width,
 		     c->disp->allocation.height);
+	
     return TRUE;
     event = NULL;
 }
@@ -323,23 +320,6 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
 
     load_graph_load_config (g);
 
-/*
-    if (g->global_prop_data == &multiload_properties.cpuload)
-	g->prop_data->type = PROP_CPULOAD;
-    else if (g->global_prop_data == &multiload_properties.memload)
-	g->prop_data->type = PROP_MEMLOAD;
-    else if (g->global_prop_data == &multiload_properties.swapload)
-	g->prop_data->type = PROP_SWAPLOAD;
-    else if (g->global_prop_data == &multiload_properties.netload)
-	g->prop_data->type = PROP_NETLOAD;
-    else if (g->global_prop_data == &multiload_properties.loadavg)
-	g->prop_data->type = PROP_LOADAVG;
-    else
-	g_assert_not_reached();
-
-    g->local_prop_data->type = g->prop_data->type;
-*/
-
     g->get_data = get_data;
 
     g->timer_index = -1;
